Name:          mraa
Version:       1.7.0
Release:       1%{?dist}
Summary:       A low level skeleton library for Industrial IO Communication
License:       MIT
URL:           http://iotdk.intel.com/docs/master/mraa/index.html
Source0:       https://github.com/intel-iot-devkit/mraa/archive/v%{version}.tar.gz
# add patch to disable network access (via git) during build
Patch0:        mraa_no-network-access-v%{version}.patch

# To quote "Only x86, arm and mock platforms currently supported"
ExcludeArch: %{power64} s390x
BuildRequires: cmake
BuildRequires: nodejs-devel nodejs-packaging
BuildRequires: python3-devel python3-setuptools
BuildRequires: swig
BuildRequires: doxygen graphviz sphinx

%description
mraa is a low level skeleton library for Industrial IO Communication and 
includes python, java and Node-JS bindings.

%package devel
Summary: Development package for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
Files for development with %{name}.

%package -n python3-iio
Summary: Python3 bindings
License: GPLv2+
Requires: %{name}%{?_isa} = %{version}-%{release}

%description -n python3-iio
Python3 bindings for Industrial IO.

%package -n nodejs-mraa
Summary: NodeJS package for mraa low-level I/O library
License: GPLv2+
Requires: %{name}%{?_isa} = %{version}-%{release}

%description -n nodejs-mraa
NodeJS bindings for Industrial IO.

%prep
%setup -q
%patch0 -p1

pushd examples/javascript
sed -i '1i #!/usr/bin/node' AioA0.js Blink-IO.js GPIO_DigitalRead.js \
    GPIO_DigitalWrite.js firmata.js gpio-tool.js initio.js \
    rgblcd.js uart.js
sed -i '1s/env //' *.js
popd
sed -i 's|bin/usr|usr/bin|' examples/python/initio.py
sed -i '1s/env //' examples/python/*.py

%build
if [ "%{_libdir}" = "%{_prefix}/lib64" ]; then
  %cmake -DCMAKE_INSTALL_PREFIX:PATH=/usr -DCMAKE_SKIP_RPATH=ON -DUSE_LIB64:BOOL=ON -DVERSION:STRING=%{version} .
else
  %cmake -DCMAKE_INSTALL_PREFIX:PATH=/usr -DCMAKE_SKIP_RPATH=ON -DUSE_LIB64:BOOL=OFF -DVERSION:STRING=%{version} .
fi

make %{?_smp_mflags} V=1
#make %{?_smp_mflags} V=1 iio_driver
#make %{?_smp_mflags} V=1 mraajs
#make %{?_smp_mflags} V=1 npmpkg
#make %{?_smp_mflags} V=1 mraa-gpio

%install
make install DESTDIR=%{buildroot} INSTALL='install -p'

#Move the examples to the proper location
mkdir -p %{buildroot}%{_libexecdir}/mraa
mv %{buildroot}%{_datarootdir}/mraa/examples/ %{buildroot}%{_libexecdir}/mraa/examples/

#Remove libtool archives.
find %{buildroot} -name '*.la' -exec rm -f {} ';'

#Set some permissions
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/javascript/*.js
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/python/*.py

chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/analogin_a0
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/blink-io
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/blink_onboard
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/c++/AioA0
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/c++/blink-io-cpp
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/c++/I2c-compass
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/c++/Iio-dummy
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/c++/Isr-pin6
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/c++/Pwm3-cycle
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/c++/Spi-pot
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/c++/Uart
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/c++/UartOW
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/cycle-pwm3
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/gpio_read6
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/hellomraa
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/i2c_HMC5883L
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/iio_driver
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/isr_pin6
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/mmap-io2
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/mraa-gpio
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/mraa-i2c
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/spi_max7219
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/spi_mcp4261
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/uart
chmod 0755 %{buildroot}%{_libexecdir}/mraa/examples/uart_ow

chmod 0755 %{buildroot}%{nodejs_sitelib}/mraa/mraa.node

# Symlink nodejs dependencies
%nodejs_symlink_deps

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license COPYING
%doc README.md CONTRIBUTING.md
%{_libdir}/lib%{name}.so.*
%{_bindir}/mraa-*

%files devel
%{_includedir}/mraa/
%{_includedir}/mraa.*
%{_libexecdir}/mraa/
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{name}.so

%files -n python3-iio
%{python3_sitearch}/*

%files -n nodejs-mraa
%{nodejs_sitelib}/mraa

%changelog
* Tue May 16 2017 Peter Robinson <pbrobinson@fedoraproject.org> 1.7.0-1
- Update to 1.7.0

* Tue Apr 25 2017 Peter Robinson <pbrobinson@fedoraproject.org> 1.6.1-2
- Review updates

* Fri Apr  7 2017 Peter Robinson <pbrobinson@fedoraproject.org> 1.6.1-1
- Update to 1.6.1

* Mon Jan  9 2017 Peter Robinson <pbrobinson@fedoraproject.org> 1.5.1-2
- Review updates

* Wed Dec  7 2016 Peter Robinson <pbrobinson@fedoraproject.org> 1.5.1-1
- Initial package
